"""ap_12 URL Configuration

The `urlpatterns` list routes URLs to views. For more information please see:
    https://docs.djangoproject.com/en/3.2/topics/http/urls/
Examples:
Function views
    1. Add an import:  from my_app import views
    2. Add a URL to urlpatterns:  path('', views.home, name='home')
Class-based views
    1. Add an import:  from other_app.views import Home
    2. Add a URL to urlpatterns:  path('', Home.as_view(), name='home')
Including another URLconf
    1. Import the include() function: from django.urls import include, path
    2. Add a URL to urlpatterns:  path('blog/', include('blog.urls'))
"""
from django.contrib import admin
from django.urls import path, include

from webapp import views

urlpatterns = [
    path('admin/', admin.site.urls),
    path('', views.IndexRedirectView.as_view(), name='redirect_to_index'),
    path('articles', views.IndexListView.as_view(), name='index'),
    path('articles/add', views.ArticleCreateView.as_view(), name='articles_add'),
    path('articles/<int:id>', views.ArticleDetailView.as_view(), name='articles_detail'),
    path('articles/<int:id>/update', views.ArticleUpdateView.as_view(), name='articles_update'),
    path('articles/<int:id>/delete', views.ArticleDeleteView.as_view(), name='articles_delete'),
    path('articles/<int:article_id>/comments/add', views.CommentCreateView.as_view(), name='comments_add'),
    path(
        'articles/<int:article_id>/comments/<int:comment_id>/update',
        views.CommentUpdateView.as_view(),
        name='comments_update',
    ),
    path(
        'articles/<int:article_id>/comments/<int:comment_id>/delete',
        views.CommentDeleteView.as_view(),
        name='comments_delete',
    ),
    
    path('accounts/', include('accounts.urls')),
]
